# CHANGELOG


## v0.3.1 (2026-01-03)

### Bug Fixes

- Correct sampling
  ([`384408a`](https://github.com/muka/tap-jsonl/commit/384408a827f2760e33ffe4a15ad03e1af63426ec))


## v0.3.0 (2026-01-03)

### Features

- Simplify schema
  ([`0b310e3`](https://github.com/muka/tap-jsonl/commit/0b310e3bc518ebe75467da3e026092ef2e202f4d))


## v0.2.3 (2026-01-03)

### Bug Fixes

- Expose props
  ([`46327cc`](https://github.com/muka/tap-jsonl/commit/46327cc0c7c93bad78f3a758c05f6188a4d4e110))

### Chores

- Fix tests
  ([`e7d6ac5`](https://github.com/muka/tap-jsonl/commit/e7d6ac5e27b26429e5c9a159f1fbf75c32b226f9))

- **deps**: Bump s3fs from 2025.10.0 to 2025.12.0
  ([`84a2773`](https://github.com/muka/tap-jsonl/commit/84a2773ffba2ba00785c74c1802e31dc5a4b77c1))

Bumps [s3fs](https://github.com/fsspec/s3fs) from 2025.10.0 to 2025.12.0. -
  [Changelog](https://github.com/fsspec/s3fs/blob/main/release-procedure.md) -
  [Commits](https://github.com/fsspec/s3fs/compare/2025.10.0...2025.12.0)

--- updated-dependencies: - dependency-name: s3fs dependency-version: 2025.12.0

dependency-type: direct:production

update-type: version-update:semver-minor ...

Signed-off-by: dependabot[bot] <support@github.com>


## v0.2.2 (2026-01-03)

### Bug Fixes

- Build
  ([`4260e9e`](https://github.com/muka/tap-jsonl/commit/4260e9eb7e4457dc2730ee5dec979416f4773989))


## v0.2.1 (2026-01-03)

### Bug Fixes

- Semvver up
  ([`6da4c84`](https://github.com/muka/tap-jsonl/commit/6da4c84651145e4ce2e46e1f4316a0e2cdbb7116))


## v0.2.0 (2026-01-03)

### Chores

- Bump uv lock
  ([`07a57ad`](https://github.com/muka/tap-jsonl/commit/07a57ad4f9761c685d562adf72d03f48fe947ce6))

### Features

- Improve samples lookup
  ([`201f655`](https://github.com/muka/tap-jsonl/commit/201f655ac67844848d5484ac64c6b68babace63f))


## v0.1.1 (2026-01-02)

### Bug Fixes

- Py3.10 support
  ([`f2f2473`](https://github.com/muka/tap-jsonl/commit/f2f247362fdb170ddbf137b1ddf97c08c1f15c56))

- Up docs, review sem release
  ([`974337b`](https://github.com/muka/tap-jsonl/commit/974337ba8274b16c42b6f6a75a72d6bf8b313494))

### Chores

- Add tests
  ([`d9a243d`](https://github.com/muka/tap-jsonl/commit/d9a243d6ea54b258413f5937bba0b42a6ba106d9))

- **deps**: Bump s3fs from 2025.10.0 to 2025.12.0
  ([`c886ef4`](https://github.com/muka/tap-jsonl/commit/c886ef4f0cbe7d1dcfcbbd4e445460edceafca28))

Bumps [s3fs](https://github.com/fsspec/s3fs) from 2025.10.0 to 2025.12.0. -
  [Changelog](https://github.com/fsspec/s3fs/blob/main/release-procedure.md) -
  [Commits](https://github.com/fsspec/s3fs/compare/2025.10.0...2025.12.0)

--- updated-dependencies: - dependency-name: s3fs dependency-version: 2025.12.0

dependency-type: direct:production

update-type: version-update:semver-minor ...

Signed-off-by: dependabot[bot] <support@github.com>


## v0.1.0 (2026-01-02)

### Features

- Add releases
  ([`3226ac3`](https://github.com/muka/tap-jsonl/commit/3226ac3b4490ab06538ee7f2721b54bec501604b))

- First version
  ([`b366813`](https://github.com/muka/tap-jsonl/commit/b3668134a97248860c549523142f5cf44cdcbb82))
